@@ -47,6 +47,8 @@ gfu_common_seconds_to_string(guint64 seconds)
 			minutes = minutes % 60;
 			return g_strdup_printf("%lu hr, %lu min, %lu sec", hours, minutes, seconds);
 		}
+		if (seconds == 0)
+			return g_strdup_printf("%lu min", minutes);
 		return g_strdup_printf("%lu min, %lu sec", minutes, seconds);
 	}
 	return g_strdup_printf("%lu sec", seconds);
@@ -114,7 +116,7 @@ gfu_common_xml_to_text(const gchar *xml, GError **error)
 }
 
 const gchar *
-gfu_common_device_flags_to_strings(guint64 flags)
+gfu_common_device_flag_to_string(guint64 flags)
 {
 	g_autoptr(GString) str = g_string_new(NULL);
 	for (guint j = 0; j < 64; j++) {
@@ -130,6 +132,50 @@ gfu_common_device_flags_to_strings(guint64 flags)
 	return g_string_free(g_steal_pointer(&str), FALSE);
 }
 
+static const gchar *
+gfu_common_release_flag_to_string(FwupdReleaseFlags release_flag)
+{
+	if (release_flag == FWUPD_RELEASE_FLAG_NONE)
+		return NULL;
+	if (release_flag == FWUPD_RELEASE_FLAG_TRUSTED_PAYLOAD) {
+		/* TRANSLATORS: We verified the payload against the server */
+		return _("Trusted payload");
+	}
+	if (release_flag == FWUPD_RELEASE_FLAG_TRUSTED_METADATA) {
+		/* TRANSLATORS: We verified the meatdata against the server */
+		return _("Trusted metadata");
+	}
+	if (release_flag == FWUPD_RELEASE_FLAG_IS_UPGRADE) {
+		/* TRANSLATORS: version is newer */
+		return _("Is upgrade");
+	}
+	if (release_flag == FWUPD_RELEASE_FLAG_IS_DOWNGRADE) {
+		/* TRANSLATORS: version is older */
+		return _("Is downgrade");
+	}
+	if (release_flag == FWUPD_RELEASE_FLAG_BLOCKED_VERSION) {
+		/* TRANSLATORS: version cannot be installed due to policy */
+		return _("Blocked version");
+	}
+	if (release_flag == FWUPD_RELEASE_FLAG_BLOCKED_APPROVAL) {
+		/* TRANSLATORS: version cannot be installed due to policy */
+		return _("Not approved");
+	}
+	if (release_flag == FWUPD_RELEASE_FLAG_IS_ALTERNATE_BRANCH) {
+		/* TRANSLATORS: is not the main firmware stream */
+		return _("Alternate branch");
+	}
+#if FWUPD_CHECK_VERSION(1, 7, 5)
+	if (release_flag == FWUPD_RELEASE_FLAG_IS_COMMUNITY) {
+		/* TRANSLATORS: is not supported by the vendor */
+		return _("Community supported");
+	}
+#endif
+
+	/* fall back for unknown types */
+	return fwupd_release_flag_to_string(release_flag);
+}
+
 const gchar *
 gfu_common_release_flags_to_strings(guint64 flags)
 {
@@ -137,13 +183,13 @@ gfu_common_release_flags_to_strings(guint64 flags)
 	for (guint j = 0; j < 64; j++) {
 		if ((flags & ((guint64)1 << j)) == 0)
 			continue;
-		g_string_append_printf(str, "%s\n", fwupd_device_flag_to_string((guint64)1 << j));
-	}
-	if (str->len == 0) {
-		g_string_append(str, fwupd_release_flag_to_string(0));
-	} else {
-		g_string_truncate(str, str->len - 1);
+		g_string_append_printf(str,
+				       "%s\n",
+				       gfu_common_release_flag_to_string((guint64)1 << j));
 	}
+	if (str->len == 0)
+		return NULL;
+	g_string_truncate(str, str->len - 1);
 	return g_string_free(g_steal_pointer(&str), FALSE);
 }
 
@@ -241,7 +287,7 @@ gfu_common_system_reboot(GError **error)
 /* GTK helper functions */
 
 gchar *
-gfu_common_device_flag_to_string(guint64 device_flag)
+gfu_common_device_flags_to_string(guint64 device_flag)
 {
 	if (device_flag == FWUPD_DEVICE_FLAG_NONE) {
 		return NULL;
@@ -490,24 +536,6 @@ gfu_common_device_icon_from_flag(FwupdDeviceFlags device_flag)
 	return NULL;
 }
 
-gchar *
-gfu_operation_to_string(GfuOperation operation, FwupdDevice *dev)
-{
-	/* show message in progressbar */
-	if (operation == GFU_OPERATION_UPDATE) {
-		/* TRANSLATORS: %1 is a device name */
-		return g_strdup_printf(_("Updating %s…"), fwupd_device_get_name(dev));
-	} else if (operation == GFU_OPERATION_DOWNGRADE) {
-		/* TRANSLATORS: %1 is a device name */
-		return g_strdup_printf(_("Downgrading %s…"), fwupd_device_get_name(dev));
-	} else if (operation == GFU_OPERATION_INSTALL) {
-		/* TRANSLATORS: %1 is a device name  */
-		return g_strdup_printf(_("Installing on %s…"), fwupd_device_get_name(dev));
-	}
-	g_warning("no GfuOperation set");
-	return NULL;
-}
-
 const gchar *
 gfu_status_to_string(FwupdStatus status)
 {
@@ -567,9 +595,7 @@ gfu_status_to_string(FwupdStatus status)
 	default:
 		break;
 	}
-
-	/* TRANSLATORS: currect daemon status is unknown */
-	return _("Unknown");
+	return fwupd_status_to_string(status);
 }
 
 gchar *
